| /llvm-project-15.0.7/mlir/lib/ExecutionEngine/ |
| H A D | CudaRuntimeWrappers.cpp | 137 extern "C" void *mgpuMemAlloc(uint64_t sizeBytes, CUstream /*stream*/) { in mgpuMemAlloc() argument 140 CUDA_REPORT_IF_ERROR(cuMemAlloc(&ptr, sizeBytes)); in mgpuMemAlloc() 148 extern "C" void mgpuMemcpy(void *dst, void *src, size_t sizeBytes, in mgpuMemcpy() argument 152 sizeBytes, stream)); in mgpuMemcpy() 166 mgpuMemHostRegister(void *ptr, uint64_t sizeBytes) { in mgpuMemHostRegister() argument 168 CUDA_REPORT_IF_ERROR(cuMemHostRegister(ptr, sizeBytes, /*flags=*/0)); in mgpuMemHostRegister() 184 uint64_t sizeBytes = sizes[0] * denseStrides[0] * elementSizeBytes; in mgpuMemHostRegisterMemRef() local 192 mgpuMemHostRegister(ptr, sizeBytes); in mgpuMemHostRegisterMemRef()
|
| H A D | RocmRuntimeWrappers.cpp | 127 extern "C" void *mgpuMemAlloc(uint64_t sizeBytes, hipStream_t /*stream*/) { in mgpuMemAlloc() argument 130 HIP_REPORT_IF_ERROR(hipMalloc(&ptr, sizeBytes)); in mgpuMemAlloc() 138 extern "C" void mgpuMemcpy(void *dst, void *src, size_t sizeBytes, in mgpuMemcpy() argument 141 hipMemcpyAsync(dst, src, sizeBytes, hipMemcpyDefault, stream)); in mgpuMemcpy() 153 extern "C" void mgpuMemHostRegister(void *ptr, uint64_t sizeBytes) { in mgpuMemHostRegister() argument 155 HIP_REPORT_IF_ERROR(hipHostRegister(ptr, sizeBytes, /*flags=*/0)); in mgpuMemHostRegister() 170 auto sizeBytes = denseStrides.front() * elementSizeBytes; in mgpuMemHostRegisterMemRef() local 179 mgpuMemHostRegister(ptr, sizeBytes); in mgpuMemHostRegisterMemRef()
|
| /llvm-project-15.0.7/mlir/lib/Conversion/MemRefToLLVM/ |
| H A D | AllocLikeConversion.cpp | 37 Value sizeBytes; in matchAndRewrite() local 39 strides, sizeBytes); in matchAndRewrite() 45 this->allocateBuffer(rewriter, loc, sizeBytes, op); in matchAndRewrite()
|
| H A D | MemRefToLLVM.cpp | 48 Location loc, Value sizeBytes, in allocateBuffer() 67 sizeBytes = rewriter.create<LLVM::AddOp>(loc, sizeBytes, alignment); in allocateBuffer() 74 auto results = createLLVMCall(rewriter, loc, allocFuncOp, {sizeBytes}, in allocateBuffer() 156 Location loc, Value sizeBytes, in allocateBuffer() 167 sizeBytes = createAligned(rewriter, loc, sizeBytes, allocAlignment); in allocateBuffer() 172 createLLVMCall(rewriter, loc, allocFuncOp, {allocAlignment, sizeBytes}, in allocateBuffer() 199 Location loc, Value sizeBytes, in allocateBuffer() 208 loc, elementPtrType, sizeBytes, allocaOp.getAlignment().value_or(0)); in allocateBuffer() 651 Location loc, Value sizeBytes, in allocateBuffer()
|
| /llvm-project-15.0.7/mlir/lib/Conversion/SPIRVToLLVM/ |
| H A D | ConvertLaunchFuncToLLVMCalls.cpp | 223 Value sizeBytes; in matchAndRewrite() local 225 sizeBytes); in matchAndRewrite() 256 copy(loc, dst, src, sizeBytes, rewriter); in matchAndRewrite() 261 info.size = sizeBytes; in matchAndRewrite()
|
| /llvm-project-15.0.7/mlir/lib/Conversion/OpenACCToLLVM/ |
| H A D | OpenACCToLLVM.cpp | 112 Value sizeBytes; in matchAndRewrite() local 114 loc, memRefType, {}, builder, sizes, strides, sizeBytes); in matchAndRewrite() 122 descr.setSize(builder, loc, sizeBytes); in matchAndRewrite()
|
| /llvm-project-15.0.7/mlir/include/mlir/Conversion/MemRefToLLVM/ |
| H A D | AllocLikeConversion.h | 37 Value sizeBytes, Operation *op) const = 0;
|
| /llvm-project-15.0.7/mlir/lib/Conversion/GPUCommon/ |
| H A D | GPUToLLVMConversion.cpp | 461 Value sizeBytes; in matchAndRewrite() local 463 shape, strides, sizeBytes); in matchAndRewrite() 470 allocCallBuilder.create(loc, rewriter, {sizeBytes, stream}).getResult(0); in matchAndRewrite() 816 auto sizeBytes = in matchAndRewrite() local 826 memcpyCallBuilder.create(loc, rewriter, {dst, src, sizeBytes, stream}); in matchAndRewrite()
|
| /llvm-project-15.0.7/mlir/lib/Conversion/LLVMCommon/ |
| H A D | Pattern.cpp | 123 SmallVectorImpl<Value> &strides, Value &sizeBytes) const { in getMemRefDescriptorSizes() 168 sizeBytes = rewriter.create<LLVM::PtrToIntOp>(loc, getIndexType(), gepPtr); in getMemRefDescriptorSizes()
|
| /llvm-project-15.0.7/mlir/include/mlir/Conversion/LLVMCommon/ |
| H A D | Pattern.h | 102 Value &sizeBytes) const;
|